==> mediawiki-1.13.2-noname-P1.tgz: opt/htdocs/mediawiki-1.13.2/languages/messages/MessagesKv.php <==
<?php
/** Komi (Коми)
 *
 * @ingroup Language
 * @file
 *
 * @author Yufereff
 * @author ОйЛ
 */

$fallback = 'ru';

$messages = array(
# Dates
'sunday'        => 'вежалун',
'monday'        => 'выльлун',
'tuesday'       => 'воторник',
'wednesday'     => 'середа',
'thursday'      => 'четверг',
'friday'        => 'пекнича',
'saturday'      => 'субöта',
'january'       => 'тӧв шӧр',
'february'      => 'урасьӧм',
'march'         => 'рака',
'april'         => 'кос му',
'may_long'      => 'ода кора',
'june'          => 'лӧддза-номъя',
'july'          => 'сора',
'august'        => 'моз',
'september'     => 'кӧч',
'october'       => 'йирым',
'november'      => 'вӧльгым',
'december'      => 'ӧшым',
'january-gen'   => 'тӧв шӧр',
'february-gen'  => 'урасьӧм',
'march-gen'     => 'рака',
'april-gen'     => 'кос му',
'may-gen'       => 'ода кора',
'june-gen'      => 'лӧддза-номъя',
'july-gen'      => 'сора',
'august-gen'    => 'моз',
'september-gen' => 'кӧч',
'october-gen'   => 'йирым',
'november-gen'  => 'вӧльгым',
'december-gen'  => 'ӧшым',

'cancel' => 'Дугӧдны',
'qbfind' => 'Корсьысьӧм',
'qbedit' => 'Веськӧдны',
'mytalk' => 'Сёрнитӧм лист бокӧй',

'search'           => 'Корсьысьӧм',
'searchbutton'     => 'Аддзыны',
'searcharticle'    => 'Вуджны',
'history_short'    => 'Важвылӧм',
'printableversion' => 'Лэдзӧм версия',
'permalink'        => 'Вежласьтӧм ыстӧд',
'edit'             => 'Веськӧдны',
'delete'           => 'Бырӧдны',
'protect'          => 'Дорйыны',
'newpage'          => 'Выль лист бок',
'talk'             => 'Сёрнитӧм',
'toolbox'          => 'Инструментъяс',
'jumptosearch'     => 'корсьысьӧм',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Быд лунся лоӧмтор',
'mainpage'             => 'Медшӧр лист бок',
'mainpage-description' => 'Медшӧр лист бок',
'portal'               => 'Йитчӧм',
'portal-url'           => 'Project:Йитчӧм портал',

'newmessageslink' => 'выль юӧртӧмъяс',
'editsection'     => 'веськӧдны',
'editold'         => 'веськӧдны',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'Гижӧд',
'nstab-user'    => 'Вӧлысь',
'nstab-project' => 'Проект йылысь',

# Login and logout pages
'yourname'                => 'Вӧлысьлӧн ним:',
'login'                   => 'Висьтасьны',
'nav-login-createaccount' => 'Висьтасьны / гижсьыны',
'userlogin'               => 'Висьтасьны али гижсьыны',
'logout'                  => 'Сеанс эштӧдӧм',
'userlogout'              => 'Сеанс эштӧдӧм',
'gotaccountlink'          => 'Висьтасьӧй',
'loginlanguagelabel'      => 'Кыв: $1',

# Edit pages
'savearticle' => 'Лист бокӧс гижны',
'newarticle'  => '(Выль)',

# History pages
'currentrev' => 'Быд лунся версия',

# Preferences page
'timezonelegend' => 'Час кытш',

# Recent changes
'hide' => 'Дзебны',

# Upload
'upload'    => 'Файл сӧвтны',
'uploadbtn' => 'Файл сӧвтны',

# Image description page
'filehist-datetime' => 'Кадпас/кад',
'filehist-user'     => 'Вӧлысь',
'filehist-comment'  => 'Пасйӧд',

# Random page
'randompage' => 'Кӧсйытӧг гижӧд',

# Miscellaneous special pages
'newpages' => 'Выль лист бокъяс',
'move'     => 'Ним вежны',

# Special:Log
'specialloguserlabel' => 'Вӧлысь:',
'log'                 => 'Журналъяс',

# Special:AllPages
'allarticles' => 'Став гижӧдъяс',

# Delete/protect/revert
'deletepage'          => 'Лист бокӧс бырӧдны',
'protect-level-sysop' => 'Администраторъяс сӧмын',

# Contributions
'contributions' => 'Вӧлысьлӧн чӧжӧс',

# What links here
'whatlinkshere' => 'Ыстӧдъяс татчӧ',

# Move page
'newtitle'    => 'Выль ним',
'movepagebtn' => 'Лист бокӧс ним вежны',

# Namespace 8 related
'allmessages' => 'Система юӧртӧмъяс',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Вӧлысьлӧн лист бокӧй',

# Special:SpecialPages
'specialpages' => 'Торъя лист бокъяс',

);

==> mediawiki-1.13.4-noname-P1.tgz: opt/htdocs/mediawiki-1.13.4/languages/messages/MessagesKv.php <==
<?php
/** Komi (Коми)
 *
 * @ingroup Language
 * @file
 *
 * @author Yufereff
 * @author ОйЛ
 */

$fallback = 'ru';

$messages = array(
# Dates
'sunday'        => 'вежалун',
'monday'        => 'выльлун',
'tuesday'       => 'воторник',
'wednesday'     => 'середа',
'thursday'      => 'четверг',
'friday'        => 'пекнича',
'saturday'      => 'субöта',
'january'       => 'тӧв шӧр тӧлысь',
'february'      => 'урасьӧм тӧлысь',
'march'         => 'рака тӧлысь',
'april'         => 'кос му тӧлысь',
'may_long'      => 'ода кора тӧлысь',
'june'          => 'лӧддза-номъя тӧлысь',
'july'          => 'сора тӧлысь',
'august'        => 'моз тӧлысь',
'september'     => 'кӧч тӧлысь',
'october'       => 'йирым тӧлысь',
'november'      => 'вӧльгым тӧлысь',
'december'      => 'ӧшым тӧлысь',
'january-gen'   => 'тӧв шӧр',
'february-gen'  => 'урасьӧм',
'march-gen'     => 'рака',
'april-gen'     => 'кос му',
'may-gen'       => 'ода кора',
'june-gen'      => 'лӧддза-номъя',
'july-gen'      => 'сора',
'august-gen'    => 'моз',
'september-gen' => 'кӧч',
'october-gen'   => 'йирым',
'november-gen'  => 'вӧльгым',
'december-gen'  => 'ӧшым',

'cancel' => 'Дугӧдны',
'qbfind' => 'Корсьысьӧм',
'qbedit' => 'Веськӧдны',
'mytalk' => 'Сёрнитӧм лист бокӧй',

'search'           => 'Корсьысьӧм',
'searchbutton'     => 'Аддзыны',
'searcharticle'    => 'Вуджны',
'history_short'    => 'Важвылӧм',
'printableversion' => 'Лэдзӧм версия',
'permalink'        => 'Вежласьтӧм ыстӧд',
'edit'             => 'Веськӧдны',
'delete'           => 'Бырӧдны',
'protect'          => 'Дорйыны',
'newpage'          => 'Выль лист бок',
'talk'             => 'Сёрнитӧм',
'toolbox'          => 'Инструментъяс',
'jumptosearch'     => 'корсьысьӧм',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Быд лунся лоӧмтор',
'mainpage'             => 'Медшӧр лист бок',
'mainpage-description' => 'Медшӧр лист бок',
'portal'               => 'Йитчӧм',
'portal-url'           => 'Project:Йитчӧм портал',

'newmessageslink' => 'выль юӧртӧмъяс',
'editsection'     => 'веськӧдны',
'editold'         => 'веськӧдны',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'Гижӧд',
'nstab-user'    => 'Вӧлысь',
'nstab-project' => 'Проект йылысь',

# Login and logout pages
'yourname'                => 'Вӧлысьлӧн ним:',
'login'                   => 'Висьтасьны',
'nav-login-createaccount' => 'Висьтасьны / гижсьыны',
'userlogin'               => 'Висьтасьны али гижсьыны',
'logout'                  => 'Сеанс эштӧдӧм',
'userlogout'              => 'Сеанс эштӧдӧм',
'gotaccountlink'          => 'Висьтасьӧй',
'loginlanguagelabel'      => 'Кыв: $1',

# Edit pages
'savearticle' => 'Лист бокӧс гижны',
'newarticle'  => '(Выль)',

# History pages
'currentrev' => 'Быд лунся версия',

# Preferences page
'timezonelegend' => 'Час кытш',

# Recent changes
'hide' => 'Дзебны',

# Upload
'upload'    => 'Файл сӧвтны',
'uploadbtn' => 'Файл сӧвтны',

# Image description page
'filehist-datetime' => 'Кадпас/кад',
'filehist-user'     => 'Вӧлысь',
'filehist-comment'  => 'Пасйӧд',

# Random page
'randompage' => 'Кӧсйытӧг гижӧд',

# Miscellaneous special pages
'newpages' => 'Выль лист бокъяс',
'move'     => 'Ним вежны',

# Special:Log
'specialloguserlabel' => 'Вӧлысь:',
'log'                 => 'Журналъяс',

# Special:AllPages
'allarticles' => 'Став гижӧдъяс',

# Delete/protect/revert
'deletepage'          => 'Лист бокӧс бырӧдны',
'protect-level-sysop' => 'Администраторъяс сӧмын',

# Contributions
'contributions' => 'Вӧлысьлӧн чӧжӧс',

# What links here
'whatlinkshere' => 'Ыстӧдъяс татчӧ',

# Move page
'newtitle'    => 'Выль ним',
'movepagebtn' => 'Лист бокӧс ним вежны',

# Namespace 8 related
'allmessages' => 'Система юӧртӧмъяс',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Вӧлысьлӧн лист бокӧй',

# Special:SpecialPages
'specialpages' => 'Торъя лист бокъяс',

);
